==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/fr_CA.php <==
<?php

return [
    'Names' => [
        'ady' => 'adygué',
        'ang' => 'vieil anglais',
        'asa' => 'asou',
        'bbj' => 'ghomala',
        'bik' => 'bicol',
        'byn' => 'bilen',
        'byv' => 'medumba',
        'chg' => 'tchagatay',
        'chn' => 'chinook',
        'ckb' => 'kurde central',
        'cr' => 'cri',
        'den' => 'slave',
        'dgr' => 'tlicho',
        'ebu' => 'embou',
        'esu' => 'yupik central',
        'ewo' => 'ewondo',
        'frc' => 'cajun',
        'frp' => 'franco-provençal',
        'goh' => 'vieux haut-allemand',
        'gu' => 'gujarati',
        'ii' => 'yi de Sichuan',
        'ken' => 'kenyang',
        'kg' => 'kongo',
        'kl' => 'kalaallisut',
        'ks' => 'kashmiri',
        'ksb' => 'chambala',
        'liv' => 'live',
        'lu' => 'luba-katanga',
        'lzh' => 'chinois classique',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mr' => 'marathe',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'njo' => 'ao naga',
        'nmg' => 'kwasio',
        'nwc' => 'newari classique',
        'nyn' => 'nkole',
        'pau' => 'palauan',
        'pdc' => 'allemand de Pennsylvanie',
        'pdt' => 'bas allemand mennonite',
        'peo' => 'vieux perse',
        'pfl' => 'palatin',
        'pro' => 'ancien occitan',
        'quc' => 'k’iche’',
        'rar' => 'rarotonga',
        'sbp' => 'sangu',
        'sdh' => 'kurde méridional',
        'sei' => 'seri',
        'sga' => 'vieil irlandais',
        'sly' => 'selayar',
        'smn' => 'sami d’Inari',
        'stq' => 'frison de Saterland',
        'sus' => 'sosso',
        'tru' => 'turoyo',
        'tzm' => 'tamazight',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabe standard moderne',
        'de_AT' => 'allemand autrichien',
        'de_CH' => 'allemand suisse',
        'en_AU' => 'anglais australien',
        'en_CA' => 'anglais canadien',
        'en_GB' => 'anglais britannique',
        'en_US' => 'anglais américain',
        'fr_CA' => 'français canadien',
        'fr_CH' => 'français suisse',
        'nds_NL' => 'bas saxon',
        'nl_BE' => 'flamand',
        'pt_BR' => 'portugais brésilien',
        'pt_PT' => 'portugais européen',
        'ro_MD' => 'moldave',
        'sw_CD' => 'swahili congolais',
        'zh_Hans' => 'chinois simplifié',
        'zh_Hant' => 'chinois traditionnel',
    ],
];

==> symfony_8.0.2+dfsg.orig.tar.xz: symfony-8.0.2/src/Symfony/Component/Intl/Resources/data/languages/fr_CA.php <==
<?php

return [
    'Names' => [
        'ady' => 'adygué',
        'ang' => 'vieil anglais',
        'asa' => 'asou',
        'bbj' => 'ghomala',
        'bik' => 'bicol',
        'byn' => 'bilen',
        'byv' => 'medumba',
        'chg' => 'tchagatay',
        'chn' => 'chinook',
        'ckb' => 'kurde central',
        'cr' => 'cri',
        'crg' => 'michif',
        'crl' => 'cri du Nord-Est',
        'crr' => 'algonquin de la Caroline',
        'den' => 'slave',
        'dgr' => 'tlicho',
        'ebu' => 'embou',
        'esu' => 'yupik central',
        'ewo' => 'ewondo',
        'frc' => 'cajun',
        'frp' => 'franco-provençal',
        'goh' => 'vieux haut-allemand',
        'gu' => 'gujarati',
        'ii' => 'yi de Sichuan',
        'ken' => 'kenyang',
        'kl' => 'kalaallisut',
        'ks' => 'kashmiri',
        'ksb' => 'chambala',
        'liv' => 'live',
        'lu' => 'luba-katanga',
        'lzh' => 'chinois classique',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'njo' => 'ao naga',
        'nmg' => 'kwasio',
        'nwc' => 'newari classique',
        'nyn' => 'nkole',
        'oka' => 'okanagan',
        'pau' => 'palauan',
        'pdc' => 'allemand de Pennsylvanie',
        'pdt' => 'bas allemand mennonite',
        'peo' => 'vieux perse',
        'pfl' => 'palatin',
        'pis' => 'pidgin',
        'pro' => 'ancien occitan',
        'quc' => 'k’iche’',
        'rar' => 'rarotonga',
        'sbp' => 'sangu',
        'sdh' => 'kurde méridional',
        'sei' => 'seri',
        'sga' => 'vieil irlandais',
        'sly' => 'selayar',
        'smn' => 'sami d’Inari',
        'stq' => 'frison de Saterland',
        'sus' => 'sosso',
        'tru' => 'turoyo',
        'tzm' => 'tamazight',
    ],
    'LocalizedNames' => [
        'nds_NL' => 'bas saxon',
        'sw_CD' => 'swahili congolais',
    ],
];
